@@ -105,7 +105,7 @@ ABBR_WORDS = {
         r"\bmisc\.": "miscellaneous",
         r"\be\.g\.": "for example",
         r"\btv\b": "T V",
-        r"\b(no\.) (\d+)": (r"number \2", 0, "number"),
+        r"\b(no\.) ?(\d+)": (r"number \2", 0, "number"),
     },
     "de": {
         r"\bz\.B\. ": "zum Beispiel",
@@ -532,6 +532,9 @@ class PhoneFormatter(BaseFormatter):
         if self.lang in ["en", "es", "pt"]:
             return phone_root[0].lower() in ["a", "e", "i", "o", "u"]
 
+        if self.lang in ["it"]:
+            return phone_root[0].lower() in ["a", "e", "i", "o", "u", "j"]
+
         # sampa common
         # https://en.wikipedia.org/wiki/SAMPA_chart
         if self.lang in ["de", "fr"]:
